@@ -43,7 +43,7 @@ static void
 draw_crossbutton( FL_OBJECT * ob,
                   int         event )
 {
-    FL_Coord xx,
+    FL_COORD xx,
              yy,
              ww,
              hh;
@@ -97,10 +97,10 @@ draw_crossbutton( FL_OBJECT * ob,
 
 FL_OBJECT *
 fl_create_crossbutton( int          type,
-                       FL_Coord     x,
-                       FL_Coord     y,
-                       FL_Coord     w,
-                       FL_Coord     h,
+                       FL_COORD     x,
+                       FL_COORD     y,
+                       FL_COORD     w,
+                       FL_COORD     h,
                        const char * label )
 {
      FL_OBJECT *ob;
@@ -119,10 +119,10 @@ fl_create_crossbutton( int          type,
 
 FL_OBJECT *
 fl_add_crossbutton( int          type,
-                    FL_Coord     x,
-                    FL_Coord     y,
-                    FL_Coord     w,
-                    FL_Coord     h,
+                    FL_COORD     x,
+                    FL_COORD     y,
+                    FL_COORD     w,
+                    FL_COORD     h,
                     const char * label )
 {
     FL_OBJECT *ob = fl_create_crossbutton( type, x, y, w, h, label );
