@@ -102,7 +102,7 @@ int
 main( int    argc,
       char * argv[ ] )
 {
-    fl_initialize( &argc, argv, "FormDemo", 0, 0 );
+    fl_initialize( &argc, argv, "FormDemo", NULL, 0 );
     ui = create_form_fontsform( );
     fl_scale_form( ui->fontsform, 1.1, 1.2 );
     fl_set_object_dblbuffer( ui->textobj, 1 );
