@@ -1,22 +1,20 @@
 /*
+ *  This file is part of XForms.
  *
- * This file is part of XForms.
+ *  XForms is free software; you can redistribute it and/or modify it
+ *  under the terms of the GNU Lesser General Public License as
+ *  published by the Free Software Foundation; either version 2.1, or
+ *  (at your option) any later version.
  *
- * XForms is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1, or
- * (at your option) any later version.
- *
- * XForms is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with XForms; see the file COPYING.  If not, write to
- * the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ *  XForms is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with XForms; see the file COPYING.  If not, write to
+ *  the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
+ *  MA 02111-1307, USA.
  */
 
 
@@ -25,7 +23,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include/forms.h"
@@ -35,13 +33,13 @@
 /**** Forms and Objects ****/
 
 typedef struct {
-	FL_FORM   * form;
-	int         timer_id;
-	void      * vdata;
-	long        ldata;
-	FL_OBJECT * timer;
-	FL_OBJECT * restart;
-	FL_OBJECT * report;
+    FL_FORM   * form;
+    int         timer_id;
+    void      * vdata;
+    long        ldata;
+    FL_OBJECT * timer;
+    FL_OBJECT * restart;
+    FL_OBJECT * report;
 } FD_form;
 
 static FD_form * create_form_form( void );
@@ -56,7 +54,7 @@ static long end_sec,
 
 static void
 exit_cb( FL_OBJECT * ob    FL_UNUSED_ARG,
-		 long        data  FL_UNUSED_ARG )
+         long        data  FL_UNUSED_ARG )
 {
    fl_finish( );
    exit( 0 );
@@ -69,7 +67,7 @@ exit_cb( FL_OBJECT * ob    FL_UNUSED_ARG,
 
 static void
 timer_cb( int    id  FL_UNUSED_ARG,
-		  void * data )
+          void * data )
 {
    char buf[ 128 ];
    double df;
@@ -83,7 +81,7 @@ timer_cb( int    id  FL_UNUSED_ARG,
    df = end_sec - start_sec + 1.0e-6 * ( end_usec - start_usec );
 
    sprintf( buf,"Timeout: %.3f  Actual: %.3f  DeltaE: %.3f",
-			timerval, df, df - timerval );
+            timerval, df, df - timerval );
 
    fl_set_object_label( fd->report, buf );
 
@@ -95,13 +93,13 @@ timer_cb( int    id  FL_UNUSED_ARG,
 
 static void
 start_timer( FL_OBJECT * ob,
-			 long        data  FL_UNUSED_ARG )
+             long        data  FL_UNUSED_ARG )
 {
    FD_form *fd = ob->form->fdui;
    char buf[ 128 ];
 
    if ( fd->timer_id )
-	   fl_remove_timeout( fd->timer_id );
+       fl_remove_timeout( fd->timer_id );
 
    fd->ldata += 200;
    sprintf( buf, "Timer accuracy testing %.3f sec ...", fd->ldata * 0.001 );
@@ -116,12 +114,12 @@ start_timer( FL_OBJECT * ob,
 
 int
 main( int    argc,
-	  char * argv[ ] )
+      char * argv[ ] )
 {
    FD_form *fd_form;
 
    
-   fl_initialize( &argc, argv, 0, 0, 0 );
+   fl_initialize( &argc, argv, "FormDemo", NULL, 0 );
    fd_form = create_form_form( );
 
    /* fill-in form initialization code */
@@ -132,7 +130,7 @@ main( int    argc,
    /* show the first form */
 
    fl_show_form( fd_form->form, FL_PLACE_CENTER, FL_FULLBORDER,
-				 "Timeout precision" );
+                 "Timeout precision" );
    fl_do_forms( );
 
    return 0;
@@ -145,25 +143,33 @@ main( int    argc,
 static FD_form *
 create_form_form(void)
 {
-	FL_OBJECT *obj;
-	FD_form *fdui = fl_calloc( 1, sizeof *fdui );
+    FL_OBJECT *obj;
+    FD_form *fdui = fl_calloc( 1, sizeof *fdui );
 
-	fdui->form = fl_bgn_form( FL_NO_BOX, 320, 130 );
+    fdui->form = fl_bgn_form( FL_NO_BOX, 320, 130 );
 
-	obj = fl_add_box( FL_UP_BOX, 0, 0, 320, 130, "" );
+    fl_add_box( FL_UP_BOX, 0, 0, 320, 130, "" );
 
-	obj = fl_add_button( FL_NORMAL_BUTTON, 210, 80, 90, 35, "Done" );
-	fl_set_object_callback( obj, exit_cb, 0 );
+    obj = fl_add_button( FL_NORMAL_BUTTON, 210, 80, 90, 35, "Done" );
+    fl_set_object_callback( obj, exit_cb, 0 );
 
-	fdui->restart = obj = fl_add_button( FL_TOUCH_BUTTON, 110, 80, 90, 35,
-										 "Restart" );
+    fdui->restart = obj = fl_add_button( FL_TOUCH_BUTTON, 110, 80, 90, 35,
+                                         "Restart" );
     fl_set_object_callback( obj, start_timer, 0 );
 
-	fdui->report = obj = fl_add_text( FL_NORMAL_TEXT, 10, 20, 290, 50,"" );
+    fdui->report = obj = fl_add_text( FL_NORMAL_TEXT, 10, 20, 290, 50,"" );
 
-	fl_end_form( );
+    fl_end_form( );
 
-	fdui->form->fdui = fdui;
+    fdui->form->fdui = fdui;
 
-	return fdui;
+    return fdui;
 }
+
+
+/*
+ * Local variables:
+ * tab-width: 4
+ * indent-tabs-mode: nil
+ * End:
+ */
