@@ -22,12 +22,10 @@
  *  This file is part of the XForms library package.
  *  Copyright (c) 1996-2002  T.C. Zhao
  *  All rights reserved.
- *
- * Temporary hack to get composite (sort of) object support in
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include/forms.h"
@@ -267,6 +265,7 @@ fli_composite_has_been_resized( FL_OBJECT * obj )
     {
         if ( obj->child )
             fli_composite_has_been_resized( obj );
+        fli_calc_object_bbox( obj );
         fli_handle_object( obj, FL_RESIZED, 0, 0, 0, NULL, 0 );
     }
 }
@@ -348,27 +347,6 @@ fl_get_object_component( FL_OBJECT * composite,
 }
 
 
-/***************************************
- ***************************************/
-
-void
-fli_mark_composite_for_redraw( FL_OBJECT * ob )
-{
-    FL_OBJECT *tmp;
-
-    for ( tmp = ob->child; tmp; tmp = tmp->nc )
-    {
-        if ( tmp->objclass == FL_BEGIN_GROUP || tmp->objclass == FL_END_GROUP )
-            continue;
-
-        if ( tmp->child && tmp->child->visible )
-            fli_mark_composite_for_redraw( tmp );
-
-        tmp->redraw = 1;
-    }
-}
-
-
 /***************************************
  * copy the parent attributes. gravity stuff is taken care of by
  * fl_add_child()
