@@ -23,12 +23,9 @@
 #include "include/forms.h"
 #include "flinternal.h"
 
-static const char *
-cv_fname( const char *f );
-
 /* These default X11 bitmap fonts may not be the most beautiful X11 fonts
    available on the system but they are part of X11 distributions since at
-   least 20 years, so we can be rather sure that they're available everywhere.
+   least 20 years, so cahnces are relatively hight that they're available.
    (And, remember, these fonts must be available on the machine where the X
    server is running on, which is not necessarily the machine where the
    program using XForms is executed.) */
@@ -59,6 +56,9 @@ static const char * bitmap_fonts[ ] =
 };
 
 
+static const char * cv_fname( const char *f );
+
+
 /* Include different sources if true type font support is enabled
    or just X11 fonts are to be used */
 
@@ -70,7 +70,6 @@ static const char * bitmap_fonts[ ] =
 #endif
 
 
-
 /***************************************
  * Convert X font names to more conventional names by stripping the
  * auxiliary info.
