@@ -151,9 +151,9 @@ xmask2button( unsigned int mask )
 
 void
 fli_do_radio_push( FL_OBJECT * obj,
-                   FL_Coord    x,
-                   FL_Coord    y,
-                   FL_Char     key,
+                   FL_COORD    x,
+                   FL_COORD    y,
+                   FL_VAL      key,
                    void      * xev,
                    int         no_callbacks )
 {
@@ -200,15 +200,15 @@ fli_do_radio_push( FL_OBJECT * obj,
 
 static int
 do_shortcut( FL_FORM  * form,
-             FL_Char    key,
-             FL_Coord   x,
-             FL_Coord   y,
+             FL_VAL     key,
+             FL_COORD   x,
+             FL_COORD   y,
              XEvent   * xev )
 {
-    FL_Char key1,
-            key2;
+    FL_VAL key1,
+           key2;
     FL_OBJECT *obj;
-    FL_Char *s;
+    FL_VAL *s;
 
     key1 = key2 = key;
 
@@ -280,9 +280,9 @@ do_shortcut( FL_FORM  * form,
 
 int
 fli_do_shortcut( FL_FORM  * form,
-                 FL_Char    key,
-                 FL_Coord   x,
-                 FL_Coord   y,
+                 FL_VAL     key,
+                 FL_COORD   x,
+                 FL_COORD   y,
                  XEvent   * xev )
 {
     int ret = do_shortcut( form, key, x, y, xev );
@@ -304,9 +304,9 @@ fli_do_shortcut( FL_FORM  * form,
 
 static void
 handle_keyboard( FL_FORM  * form,
-                 FL_Char    key,
-                 FL_Coord   x,
-                 FL_Coord   y,
+                 FL_VAL     key,
+                 FL_COORD   x,
+                 FL_COORD   y,
                  void     * xev )
 {
     FL_OBJECT *obj,
@@ -422,11 +422,11 @@ handle_keyboard( FL_FORM  * form,
 void
 fli_handle_form( FL_FORM * form,
                  int       event,
-                 FL_Char   key,
+                 FL_VAL    key,
                  XEvent  * xev )
 {
     FL_OBJECT *obj = NULL;
-    FL_Coord x,
+    FL_COORD x,
              y;
 
     if ( ! form || form->visible != FL_VISIBLE )
@@ -637,7 +637,7 @@ static int ignored_fake_configure;
 static int
 button_is_really_down( void )
 {
-    FL_Coord x,
+    FL_COORD x,
              y;
     unsigned int km;
 
@@ -714,10 +714,6 @@ do_interaction_step( int wait_io )
 
         case FocusOut:
             fli_int.keyform = NULL;
-#if defined XlibSpecificationRelease
-//            if ( fli_context->xic )
-//                XUnsetICFocus( fli_context->xic );
-#endif
             break;
 
         case KeyPress:
@@ -1048,6 +1044,28 @@ handle_EnterNotify_event( FL_FORM * evform )
     fli_int.keymask   = st_xev.xcrossing.state;
     fli_int.query_age = 0;
 
+#if defined XlibSpecificationRelease
+    /* If we've got an input context and the window changed we've got
+       to switch it to the new window. Before we do so we also reset it
+       - it might be in an intermediate state (the reset function retirns
+       a string that needs to be freed) */
+
+    if ( fli_context->xic && fli_context->xic_win != win )
+    {
+#if defined X_HAVE_UTF8_STRING
+        XFree( Xutf8ResetIC( fli_context->xic ) );
+#else
+        XFree( XmbResetIC( fli_context->xic ) );
+#endif
+        XUnsetICFocus( fli_context->xic );
+        XSetICValues( fli_context->xic,
+                      XNFocusWindow, win,
+                      ( char * ) NULL );
+        XSetICFocus( fli_context->xic );
+        fli_context->xic_win = win;
+    }
+#endif
+
     if (    button_down( fli_int.keymask )
          && st_xev.xcrossing.mode != NotifyUngrab )
         return;
@@ -1056,21 +1074,6 @@ handle_EnterNotify_event( FL_FORM * evform )
         fli_handle_form( fli_int.mouseform, FL_LEAVE,
                          xmask2button( fli_int.keymask ), &st_xev );
 
-#if defined XlibSpecificationRelease
-    /* If we've got aN input context and the window changed we've got
-       to tell it about the new window */
-
-    if ( fli_context->xic && fli_context->xic_win != win )
-    {
-        fli_context->xic_win = win;
-        XSetICValues( fli_context->xic,
-                      XNFocusWindow, win,
-                      XNClientWindow, win,
-                      ( char * ) NULL );
-        XSetICFocus( fli_context->xic );
-    }
-#endif
-
     if ( evform )
     {
         fli_int.mouseform = evform;
@@ -1269,7 +1272,7 @@ handle_Expose_event( FL_FORM  * evform,
 
     if ( ignored_fake_configure )
     {
-        FL_Coord neww,
+        FL_COORD neww,
                  newh;
 
         M_warn( "handle_Expose_event", "Run into trouble - correcting it" );
