@@ -29,17 +29,17 @@ typedef enum {
 /***** Routines *****/
 
 FL_EXPORT FL_OBJECT * fl_create_counter( int          type,
-                                         FL_Coord     x,
-                                         FL_Coord     y,
-                                         FL_Coord     w,
-                                         FL_Coord     h,
+                                         FL_COORD     x,
+                                         FL_COORD     y,
+                                         FL_COORD     w,
+                                         FL_COORD     h,
                                          const char * label );
 
 FL_EXPORT FL_OBJECT * fl_add_counter( int          type,
-                                      FL_Coord     x,
-                                      FL_Coord     y,
-                                      FL_Coord     w,
-                                      FL_Coord     h,
+                                      FL_COORD     x,
+                                      FL_COORD     y,
+                                      FL_COORD     w,
+                                      FL_COORD     h,
                                       const char * label );
 
 FL_EXPORT void fl_set_counter_value( FL_OBJECT * ob,
