@@ -41,9 +41,9 @@
 static int
 handle_lframe( FL_OBJECT * ob,
                int         event,
-               FL_Coord    mx   FL_UNUSED_ARG,
-               FL_Coord    my   FL_UNUSED_ARG,
-               FL_Char     key  FL_UNUSED_ARG,
+               FL_COORD    mx   FL_UNUSED_ARG,
+               FL_COORD    my   FL_UNUSED_ARG,
+               FL_VAL      key  FL_UNUSED_ARG,
                void      * ev   FL_UNUSED_ARG )
 {
     int sx,
@@ -53,8 +53,7 @@ handle_lframe( FL_OBJECT * ob,
         align,
         bw = FL_abs( ob->bw ),
         dy;
-    int margin,
-        len;
+    int margin;
 
     switch ( event )
     {
@@ -73,14 +72,14 @@ handle_lframe( FL_OBJECT * ob,
         case FL_DRAW :
             fl_draw_frame( ob->type, ob->x, ob->y, ob->w, ob->h,
                            ob->col1, ob->bw );
-            /* fall through */
+            break;
 
         case FL_DRAWLABEL :
-            if ( ! ( len = strlen( ob->label ) ) )
-                return 0;
+            if ( ! *ob->label )
+                break;
 
             fl_get_string_dimension( ob->lstyle, ob->lsize,
-                                     ob->label, len, &sw, &sh );
+                                     ob->label, strlen( ob->label ), &sw, &sh );
 
             align = fl_to_outside_lalign( ob->align );
 
@@ -155,10 +154,10 @@ handle_lframe( FL_OBJECT * ob,
 
 FL_OBJECT *
 fl_create_labelframe( int          type,
-                      FL_Coord     x,
-                      FL_Coord     y,
-                      FL_Coord     w,
-                      FL_Coord     h,
+                      FL_COORD     x,
+                      FL_COORD     y,
+                      FL_COORD     w,
+                      FL_COORD     h,
                       const char * label )
 {
     FL_OBJECT *ob;
@@ -181,10 +180,10 @@ fl_create_labelframe( int          type,
 
 FL_OBJECT *
 fl_add_labelframe( int          type,
-                   FL_Coord     x,
-                   FL_Coord     y,
-                   FL_Coord     w,
-                   FL_Coord     h,
+                   FL_COORD     x,
+                   FL_COORD     y,
+                   FL_COORD     w,
+                   FL_COORD     h,
                    const char * label )
 {
     FL_OBJECT *ob = fl_create_labelframe( type, x, y, w, h, label );
