@@ -27,7 +27,7 @@
 #define FLI_LIGHTBUTTON_ALIGN        ( FL_ALIGN_CENTER | FL_ALIGN_INSIDE )
 #define FLI_LIGHTBUTTON_TOPCOL       FL_COL1
 #define FLI_LIGHTBUTTON_MCOL         FL_MCOL
-#define FLI_LIGHTBUTTON_MINSIZE      ( ( FL_Coord ) 12 )
+#define FLI_LIGHTBUTTON_MINSIZE      ( ( FL_COORD ) 12 )
 
 
 #endif /* PLIGHTBUT_H */
