@@ -41,13 +41,13 @@
 static int UL_thickness = -1;
 static int UL_propwidth = 1;    /* 1 for proportional, 0 for constant */
 
-static void do_underline( FL_Coord,
-                          FL_Coord,
+static void do_underline( FL_COORD,
+                          FL_COORD,
                           const char *,
                           int );
 
-static void do_underline_all( FL_Coord,
-                              FL_Coord,
+static void do_underline_all( FL_COORD,
+                              FL_COORD,
                               const char *,
                               int,
                               unsigned long *,
@@ -86,7 +86,7 @@ typedef int ( * DrawString )( Display    * display,
 #endif
 #endif
 
-#define NUM_LINES_INCREMENT  64
+#define NUM_LINES_INCREMENT  32
 
 static struct LINE_INFO {
     char * str;
@@ -103,6 +103,7 @@ static int max_pixelline = 0;
 
 
 /***************************************
+ * Increases the pool available for lines of text to be drawn
  ***************************************/
 
 static int
@@ -114,6 +115,7 @@ extend_workmem( int nl )
 
 
 /***************************************
+ * Free the pool of memory for lines
  ***************************************/
 
 void
@@ -173,10 +175,10 @@ fli_get_max_pixels_line( void )
 
 int
 fli_draw_string( int           align,
-                 FL_Coord      x,
-                 FL_Coord      y,
-                 FL_Coord      w,
-                 FL_Coord      h,
+                 FL_COORD      x,
+                 FL_COORD      y,
+                 FL_COORD      w,
+                 FL_COORD      h,
                  int           clip,
                  FL_COLOR      backcol,
                  FL_COLOR      forecol,
@@ -190,7 +192,11 @@ fli_draw_string( int           align,
                  int           img,
                  int           topline,
                  int           endline,
+#if FL_ENABLE_XFT
+                 FL_COLOR      bkcol  FL_UNUSED_ARG )
+#else
                  FL_COLOR      bkcol )
+#endif
 {
     int i;
     int lnumb = 0;           /* number of lines in string */
@@ -203,6 +209,7 @@ fli_draw_string( int           align,
     XftFont * font = fl_get_font_struct( style, size );
 #else
 #if defined X_HAVE_UTF8_STRING
+    XFontSet font_set;
     DrawString drawIt = img ? Xutf8DrawImageString : Xutf8DrawString;
 #else
     DrawString drawIt = img ? XDrawImageString : XDrawString;
@@ -268,6 +275,10 @@ fli_draw_string( int           align,
        for that make sure the correct font is set up */
 
     fl_set_font( style, size );
+#if ! FL_ENABLE_XFT && defined X_HAVE_UTF8_STRING
+    font_set = fl_get_font_set( style, size );
+#endif
+
     fli_get_hv_align( align, &horalign, &vertalign );
 
     for ( i = topline; i < endline; i++ )
@@ -320,7 +331,7 @@ fli_draw_string( int           align,
                 break;
 
             case FL_ALIGN_CENTER :
-                line->x = x + 0.5 * ( w - width );
+                line->x = FL_crnd( x + 0.5 * ( w - width ) );
                 break;
 
             case FL_ALIGN_RIGHT :
@@ -339,8 +350,9 @@ fli_draw_string( int           align,
                 break;
 
             case FL_ALIGN_CENTER :
-                line->y =   y + 0.5 * h + ( i - 0.5 * lnumb ) * flx->fheight
-                          + flx->fasc;
+                line->y = FL_crnd(   y + 0.5 * h + ( i - 0.5 * lnumb )
+                                             * flx->fheight
+                                   + flx->fasc );
                 break;
 
             case FL_ALIGN_BOTTOM :
@@ -361,7 +373,9 @@ fli_draw_string( int           align,
     /* Set foreground and background color for text */
 
     fli_textcolor( forecol );
+#if ! FL_ENABLE_XFT
     fli_bk_textcolor( bkcol );
+#endif
 
     /* Draw all the lines requested */
 
@@ -389,7 +403,7 @@ fli_draw_string( int           align,
                      ( const XftChar8 * ) line->str, line->len, img );
 #else
 #if defined X_HAVE_UTF8_STRING
-        drawIt( flx->display, flx->win, fl_get_font_set( style, size ),
+        drawIt( flx->display, flx->win, font_set,
                 flx->textgc, line->x, line->y, line->str, line->len );
 #else
         drawIt( flx->display, flx->win, flx->textgc,
@@ -448,7 +462,7 @@ fli_draw_string( int           align,
 #else
             fli_textcolor( backcol );
 #if defined X_HAVE_UTF8_STRING
-            drawIt( flx->display, flx->win,  fl_get_font_set( style, size ),
+            drawIt( flx->display, flx->win, font_set,
                     flx->textgc, xsel, line->y, line->str + start, len );
 #else
             drawIt( flx->display, flx->win, flx->textgc, xsel,
@@ -514,14 +528,14 @@ fli_draw_string( int           align,
         if ( horalign == FL_ALIGN_LEFT )
             xc = x;
         else if ( horalign == FL_ALIGN_CENTER )
-            xc = x + 0.5 * w - 1;
+            xc = FL_crnd( x + 0.5 * w - 1 );
         else
             xc = x + w - 2;
 
         if ( vertalign == FL_ALIGN_BOTTOM )
             yc = y + h - 1 - flx->fasc;
         else if ( vertalign == FL_ALIGN_CENTER )
-            yc = y + 0.5 * ( h - flx->fheight );
+            yc = FL_crnd( y + 0.5 * ( h - flx->fheight ) );
         else
             yc = y;
 
@@ -614,14 +628,14 @@ fl_get_label_char_at_mouse( FL_OBJECT * obj )
 
 int
 fli_get_pos_in_string( int          align,
-                       FL_Coord     x,
-                       FL_Coord     y,
-                       FL_Coord     w,
-                       FL_Coord     h,
+                       FL_COORD     x,
+                       FL_COORD     y,
+                       FL_COORD     w,
+                       FL_COORD     h,
                        int          style,
                        int          size,
-                       FL_Coord     xpos,
-                       FL_Coord     ypos,
+                       FL_COORD     xpos,
+                       FL_COORD     ypos,
                        const char * str,
                        int        * xp,
                        int        * yp,
@@ -660,7 +674,7 @@ fli_get_pos_in_string( int          align,
 
     while ( p )
     {
-        if ( lnumb + 1 >= nlines )
+        if ( lnumb >= nlines )
             extend_workmem( nlines + NUM_LINES_INCREMENT );
 
         lines[ lnumb ].str = ( char * ) p;
@@ -680,7 +694,7 @@ fli_get_pos_in_string( int          align,
             break;
 
         case FL_ALIGN_CENTER :
-            toppos = y + 0.5 * ( h - lnumb * fheight );
+            toppos = FL_crnd( y + 0.5 * ( h - lnumb * fheight ) );
             break;
 
         case FL_ALIGN_BOTTOM :
@@ -723,7 +737,7 @@ fli_get_pos_in_string( int          align,
             break;
 
         case FL_ALIGN_CENTER :
-            xstart = x + 0.5 * ( w - width );
+            xstart = FL_crnd( x + 0.5 * ( w - width ) );
             break;
 
         case FL_ALIGN_RIGHT :
@@ -798,10 +812,10 @@ fli_get_pos_in_string( int          align,
 
 static void
 fli_draw_text_cursor( int          align,   /* alignment in box */
-                      FL_Coord     x,       /* bounding box geometry */
-                      FL_Coord     y,
-                      FL_Coord     w,
-                      FL_Coord     h,
+                      FL_COORD     x,       /* bounding box geometry */
+                      FL_COORD     y,
+                      FL_COORD     w,
+                      FL_COORD     h,
                       const char * str,     /* string to draw */
                       int          style,   /* font style and size */
                       int          size,
@@ -822,10 +836,10 @@ fli_draw_text_cursor( int          align,   /* alignment in box */
 
 void
 fl_draw_text_cursor( int          align,   /* alignment in box */
-                     FL_Coord     x,       /* box geometry */
-                     FL_Coord     y,
-                     FL_Coord     w,
-                     FL_Coord     h,
+                     FL_COORD     x,       /* box geometry */
+                     FL_COORD     y,
+                     FL_COORD     w,
+                     FL_COORD     h,
                      FL_COLOR     c,       /* text color */
                      int          style,   /* font style and size */
                      int          size,
@@ -839,18 +853,19 @@ fl_draw_text_cursor( int          align,   /* alignment in box */
 
 
 /***************************************
+ * Draws text inside of a box
  ***************************************/
 
-#define D( x, y, c )                                      \
+#define D( x, y, c, bk )                                     \
     fli_draw_text_cursor( align, x, y, w, h, str,         \
                           style, size, c, bc, 0, bk, -1 )
 
 void
 fli_draw_text_inside( int          align,
-                      FL_Coord     x,
-                      FL_Coord     y,
-                      FL_Coord     w,
-                      FL_Coord     h,
+                      FL_COORD     x,
+                      FL_COORD     y,
+                      FL_COORD     w,
+                      FL_COORD     h,
                       const char * str,
                       int          style,
                       int          size,
@@ -902,33 +917,51 @@ fli_draw_text_inside( int          align,
 
     /* Take care of special effects stuff  */
 
+#if FL_ENABLE_XFT
+    if ( special && bk )
+        fli_draw_text_cursor( align, x, y, w, h, str, style, size,
+                              c, bc, FL_NOCOLOR, bk, -1 );
+#endif
+
+    if ( special && bk )
+        fli_draw_text_cursor( align, x, y, w, h, str, style, size,
+                              c, bc, FL_NOCOLOR, bk, -1 );
+
     if ( special == FL_SHADOW_STYLE )
     {
         int e = size / 18 + 2;
 
-        D( x + e, y + e, FL_RIGHT_BCOL );
+        D( x + e, y + e, FL_RIGHT_BCOL, bk );
     }
     else if ( special == FL_ENGRAVED_STYLE )
     {
         int e = size / 36 + 1;
 
-        D( x - e, y,     FL_RIGHT_BCOL );
-        D( x,     y - e, FL_RIGHT_BCOL );
-        D( x - e, y - e, FL_RIGHT_BCOL );
-        D( x + e, y,     FL_TOP_BCOL );
-        D( x,     y + e, FL_TOP_BCOL );
-        D( x + e, y + e, FL_TOP_BCOL );
+#if FL_ENABLE_XFT
+        D( x + e, y,     FL_TOP_BCOL, bk );
+#else
+        D( x + e, y,     FL_TOP_BCOL, 0 );
+#endif
+        D( x,     y + e, FL_TOP_BCOL, 0 );
+        D( x + e, y + e, FL_TOP_BCOL, 0 );
+        D( x - e, y,     FL_RIGHT_BCOL, 0 );
+        D( x,     y - e, FL_RIGHT_BCOL, 0 );
+        D( x - e, y - e, FL_RIGHT_BCOL, 0 );
     }
     else if ( special == FL_EMBOSSED_STYLE )
     {
         int e = size / 36 + 1;
 
-        D( x - e, y,     FL_TOP_BCOL );
-        D( x,     y - e, FL_TOP_BCOL );
-        D( x - e, y - e, FL_TOP_BCOL );
-        D( x + e, y,     FL_RIGHT_BCOL );
-        D( x,     y + e, FL_RIGHT_BCOL );
-        D( x + e, y + e, FL_RIGHT_BCOL );
+#if FL_ENABLE_XFT
+        D( x - e, y,     FL_TOP_BCOL, bk );
+#else
+        D( x - e, y,     FL_TOP_BCOL, 0 );
+#endif
+        D( x,     y - e, FL_TOP_BCOL, 0 );
+        D( x - e, y - e, FL_TOP_BCOL, 0 );
+        D( x + e, y,     FL_RIGHT_BCOL, 0 );
+        D( x,     y + e, FL_RIGHT_BCOL, 0 );
+        D( x + e, y + e, FL_RIGHT_BCOL, 0 );
     }
 
     fli_draw_text_cursor( align, x, y, w, h, str, style, size,
@@ -942,10 +975,10 @@ fli_draw_text_inside( int          align,
 
 void
 fl_draw_text( int          align,
-              FL_Coord     x,
-              FL_Coord     y,
-              FL_Coord     w,
-              FL_Coord     h,
+              FL_COORD     x,
+              FL_COORD     y,
+              FL_COORD     w,
+              FL_COORD     h,
               FL_COLOR     c,
               int          style,
               int          size,
@@ -956,14 +989,15 @@ fl_draw_text( int          align,
 
 
 /***************************************
+ * Draws a text beside a box
  ***************************************/
 
 void
 fl_draw_text_beside( int          align,
-                     FL_Coord     x,
-                     FL_Coord     y,
-                     FL_Coord     w,
-                     FL_Coord     h,
+                     FL_COORD     x,
+                     FL_COORD     y,
+                     FL_COORD     w,
+                     FL_COORD     h,
                      FL_COLOR     c,
                      int          style,
                      int          size,
@@ -1005,10 +1039,16 @@ fl_draw_text_beside( int          align,
     y += dy;
 
     fli_get_outside_align( align, x, y, w, h, &newa, &newx, &newy );
-    fl_draw_text( newa, newx, newy, w, h, c, style, size, str );
+
+#if FL_ENABLE_XFT
+    fli_draw_text_inside( newa, newx, newy, w, h, str, style, size, c, 0, 1 );
+#else
+    fli_draw_text_inside( newa, newx, newy, w, h, str, style, size, c, 0, 0 );
+#endif
 }
 
 
+
 /***************************************
  * Do underlined text, single character only
  * if underline width to be proportional or fixed width
@@ -1028,6 +1068,9 @@ fli_set_ul_property( int prop,
 #define NARROW( c ) ( c == 'i' || c == 'j' || c == 'l' || c == 'f' || c == '1' )
 
 /***************************************
+ * Tries to determine the posiion and size needed for underlining the
+ * first 'n' characters in 'str' (or one less if the first character
+ * is the "magic underline" character)
  ***************************************/
 
 XRectangle *
@@ -1037,8 +1080,8 @@ fli_get_underline_rect(
 #else
                         XFontStruct * fs,
 #endif
-                        FL_Coord      x,
-                        FL_Coord      y,
+                        FL_COORD      x,
+                        FL_COORD      y,
                         const char  * str,
                         int           n )
 {
@@ -1100,11 +1143,12 @@ fli_get_underline_rect(
 
 
 /***************************************
+ * Draws the Underline for the first 'n' characters of 'str'
  ***************************************/
 
 static void
-do_underline( FL_Coord     x,
-              FL_Coord     y,
+do_underline( FL_COORD     x,
+              FL_COORD     y,
               const char * cstr,
               int          n )
 {
@@ -1126,12 +1170,12 @@ do_underline( FL_Coord     x,
 
 
 /***************************************
- * Underline whole string
+ * Underline a whole string
  ***************************************/
 
 static void
-do_underline_all( FL_Coord        x,
-                  FL_Coord        y,
+do_underline_all( FL_COORD        x,
+                  FL_COORD        y,
                   const char    * str,
                   int             n,
                   unsigned long * ul_pos,
@@ -1186,7 +1230,8 @@ do_underline_all( FL_Coord        x,
 
 
 /***************************************
- * Draw a single line string with embedded tabs
+ * Draw a single line (i.e. a string without any embedded '\n'),
+ * but with embedded tabs
  ***************************************/
 
 int
@@ -1200,15 +1245,15 @@ fli_draw_stringTAB( Drawable     win,
                     int          len,
                     int          img )
 {
-    int w, tab;
-    const char *p,
-               *q;
+    int w, tab_width;
+    const char *q;
 #if FL_ENABLE_XFT
     XftFont * fs;
 #else
     GC gc;
     XFontStruct * fs;
 #if defined X_HAVE_UTF8_STRING
+    XFontSet font_set;
     DrawString drawIt = img ? Xutf8DrawImageString : Xutf8DrawString;
 #else
     DrawString drawIt = img ? XDrawImageString : XDrawString;
@@ -1216,17 +1261,24 @@ fli_draw_stringTAB( Drawable     win,
     FL_COORD cx, cy, cw, ch;
 #endif
 
-    if ( win == None )
+    if ( ! win || ! s || ! *s || len == 0 || size <= 0  )
         return 0;
 
+    /* Load (or get) the required font */
+
 #if FL_ENABLE_XFT
     fs = fl_get_font_struct( style, size );
 #else
     gc = XCreateGC( flx->display, win, 0, NULL );
     fs = fl_get_font_struct( style, size );
+#if defined X_HAVE_UTF8_STRING
+    font_set = fl_get_font_set( style, size );
+#endif
 #endif
 
-    tab = fli_get_tabpixels( fs );
+    /* Figure out how wide a tab is (approximately) */
+
+    tab_width = fli_get_tabpixels( fs );
 
 #if ! FL_ENABLE_XFT
     XSetFont( flx->display, gc, fs->fid );
@@ -1237,34 +1289,55 @@ fli_draw_stringTAB( Drawable     win,
         fl_set_gc_clipping( gc, cx, cy, cw, ch );
 #endif
 
-    for ( w = 0, q = s; *q && ( p = strchr( q, '\t' ) ) && p - s < len;
-          q = p + 1 )
+    /* Split up the string at tabs and draw each part on its own, advancing
+       to the next tab positions */
+
+    w = 0;
+    q = s;
+
+    while ( *q == '\t' && q < s + len )
     {
+        w += tab_width;
+        q++;
+    }
+
+    while ( q < s + len )
+    {
+        const char * p = strchr( q, '\t' );
+
+        if ( ! p || p > s + len )
+            p = s + len;
+
 #if FL_ENABLE_XFT
         draw_string( flx->display, fs, color, x + w, y,
-                     ( const XftChar8 * ) q, s - q, img );
+                     ( const XftChar8 * ) q, p - q, img );
 #else
 #if defined X_HAVE_UTF8_STRING
-        drawIt( flx->display, win,  fl_get_font_set( style, size ),
-                gc, x + w, y, ( char * ) q, p - q );
+        drawIt( flx->display, win, font_set, gc, x + w, y,
+                ( char * ) q, p - q );
 #else
         drawIt( flx->display, win, gc, x + w, y, ( char * ) q, p - q );
 #endif
 #endif
-        w = ( ( w + fli_get_string_width( fs, q, p - q ) ) / tab + 1 ) * tab;
+
+        if ( p == s + len )
+            break;
+
+        /* Figure where the next substring must be drawn */
+
+        w =   ( ( w + fli_get_string_width( fs, q, p - q ) ) / tab_width + 1 )
+            * tab_width;
+
+        q = p + 1;
+
+        while ( *q == '\t' && q < s + len )
+        {
+            w += tab_width;
+            q++;
+        }
     }
 
-#if FL_ENABLE_XFT
-    draw_string( flx->display, fs, color, x + w, y,
-                 ( const XftChar8 * ) q, s - q + len, img );
-#else
-#if defined X_HAVE_UTF8_STRING
-    drawIt( flx->display, win,  fl_get_font_set( style, size ), gc,
-            x + w, y, ( char * ) q, s - q + len );
-#else
-    drawIt( flx->display, win, gc, x + w, y, ( char * ) q, s - q + len );
-#endif
-
+#if ! FL_ENABLE_XFT
     if ( cw > 0 || ch > 0 )
         fl_unset_gc_clipping( gc );
     XFreeGC( flx->display, gc );
@@ -1293,10 +1366,13 @@ draw_string( Display        * display,
     {
         XGlyphInfo extents;
 
+#if defined X_HAVE_UTF8_STRING
         XftTextExtentsUtf8( display, font, str, len, &extents );
-
-        XftDrawRect( flx->bgdraw, &flx->bktextcolor, x, y,
-                     extents.width, font->height );
+#else
+        XftTextExtents8( display, font, str, len, &extents );
+#endif
+        XftDrawRect( flx->bgdraw, &flx->bktextcolor, x - extents.x,
+                     y - extents.y, extents.width, extents.height );
     }
 
     fli_textcolor( fg_color );
